c ======================================================================
	PROGRAM distance
c ======================================================================
c	Author:	Iain McDonald
c	Date:	14 Nov 2004
c	Purpose: Output distances to pulsars using a variety of methods,
c		given inputs of dispersion measure (DM), and galactic
c		latitude and longitude (b, l).
c ----------------------------------------------------------------------
c ..,....1....,....2....,....3....,....4....,....5....,....6....,....7..	

	IMPLICIT NONE

	INTEGER :: IARGC		! Flag check
	REAL :: DM			! Distance modulus
	REAL :: l			! Galactic longitude
	REAL :: b			! Galactic latitude
	CHARACTER (20) :: arg		! Dummy argument
	INTEGER :: i			! Dummy loop number
	CHARACTER (255) :: filename	! Output filename
	CHARACTER (1) :: dummy		! Dummy string
	INTEGER :: char			! Character position
	INTEGER :: model		! Model type
	REAL :: dist (5)		! Output distances

	WRITE(*,*) 'Launching code...' 

c Check for flags
	IF (IARGC() .ne. 0) THEN
		WRITE(*,*) 'Flags found'
	ELSE
	   WRITE(*,*) 'ERROR: No flags found!'
	   WRITE(*,*) 'Usage: distance -dmNNN.nn -lNNN.nn -bNNN.nn'
	   WRITE(*,*) '   dm = Dispersion Measure'
	   WRITE(*,*) '   l  = Galactic Longitude'
	   WRITE(*,*) '   b  = Galactic Latitude'
	   WRITE(*,*) '   <Replace NNN.nn with values>'
	   WRITE(*,*) 'E.G. > distance -dm100 -l45 -b10'
	   WRITE(*,*) 'Insufficient input - exiting program'
	   STOP
	END IF

c Read in flags
	WRITE (*,*) 'Reading', IARGC(), ' flags'
	DO 1 i=1, IARGC()
		CALL getarg(i, arg)
		IF (arg(1:1) .eq. '-') arg = arg(2:)
		SELECT CASE (arg(1:1))
		CASE ('d')
			IF (arg(2:2) .ne. 'm') THEN
				WRITE (*,*) 'Flag <d> found!'
				WRITE (*,*) 'Did you mean <dm>?'
				STOP
			END IF
			READ (arg(3:),*) DM
			WRITE(*,*) 'Identified DM:', DM, ' pc cm^-3'
		CASE ('l')
			READ (arg(2:),*) l
			WRITE(*,*) 'Identified l: ', l, ' degrees'
		CASE ('b')
			READ (arg(2:),*) b
			WRITE(*,*) 'Identified b: ', b, ' degrees'
		CASE DEFAULT
			WRITE(*,*) 'Unidentified flag!'
			WRITE(*,*) 'Usage: dm# l# b# [f=FILE]'
			WRITE(*,*) '  where # is a number'
			WRITE(*,*) 'Problem flag:  ', arg
			STOP
		END SELECT
1	CONTINUE

	WRITE(*,*) 'Running program using:'
	WRITE(*,*) '	Dispersion measure:', DM, ' pc cm^-3'
	WRITE(*,*) '	Galactic longitude:', l, ' deg'
	WRITE(*,*) '	Galactic latitude: ', b, ' deg'
	WRITE(*,*)

c Run methods

	CALL dmdist(dm,l,b,0,dist(0))
	WRITE (*,*) 'Model: LMT       Dist:', dist(0), 'kpc'
	CALL dmdist(dm,l,b,1,dist(1))
	WRITE (*,*) 'Model: BWHV      Dist:', dist(1), 'kpc'
	CALL dmdist(dm,l,b,2,dist(2))
	WRITE (*,*) 'Model: CWFSR     Dist:', dist(2), 'kpc'
	CALL dmdist(dm,l,b,3,dist(3))
	WRITE (*,*) 'Model: TC        Dist:', dist(3), 'kpc'
	CALL dmdist(dm,l,b,4,dist(4))
	WRITE (*,*) 'Model: Gomez+al  Dist:', dist(4), 'kpc'
	CALL dmdist(dm,l,b,5,dist(5))
	WRITE (*,*) 'Model: NE2001    Dist:', dist(5), 'kpc'

	END
